
/**
 * Computation server
 *
 * @author Christophe Rippert
 */

import java.net.InetAddress;

import java.rmi.registry.Registry;
import java.rmi.registry.LocateRegistry;
import java.rmi.RemoteException;
import java.rmi.RMISecurityManager;

import java.rmi.server.RemoteServer;
import java.rmi.server.ServerNotActiveException;
import java.rmi.server.UnicastRemoteObject;

final public class Server extends UnicastRemoteObject implements ServerItf {

    public Server() throws RemoteException {
		super();
    }

    final public Object execute(String command, int a, int b) throws RemoteException {
	try {
	    System.out.println("Received command \"" + command + "\" from " + RemoteServer.getClientHost());
	} catch (ServerNotActiveException e) {
	    e.printStackTrace();
	    System.exit(-1);
	}
	if (command.equals(HELP)) {
	    return HELP_STR;
	} else if (command.equals(QUIT)) {
	    return BYE_STR;
	} else if (command.equals(ADD)) {
	    return new Integer(a + b);
	} else if (command.equals(MUL)) {
	    return new Integer(a * b);
	} else {
	    return ERROR_STR;
	}
    }

    final public static void main( String args[] ) throws Exception {
		if (args.length != 1) {
			System.err.println("usage: java Server <registry port>");
			System.exit(-1);
		}
		
		System.setSecurityManager(new RMISecurityManager());
		Server server = new Server();
		
		LocateRegistry.getRegistry(Integer.parseInt(args[0])).rebind(SIGNATURE_STR, server);
		System.out.println("Server is ready...");
    }

}
